/* 
 * DNet eBusiness Suite
 * Copyright: Nan21 Electronics SRL. All rights reserved.
 * Use is subject to license terms.
 */

package net.nan21.dnet.module.ad.workflow.domain.entity;

import java.util.Date;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.QueryHint;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;
import javax.persistence.Transient;
import javax.validation.constraints.NotNull;
import net.nan21.dnet.core.api.model.IModelWithId;
import net.nan21.dnet.core.domain.eventhandler.DefaultEventHandler;
import net.nan21.dnet.module.ad.workflow.domain.entity.ActProcessDefinition;
import org.eclipse.persistence.annotations.Cache;
import org.eclipse.persistence.annotations.CacheType;
import org.eclipse.persistence.annotations.Customizer;
import org.eclipse.persistence.config.HintValues;
import org.eclipse.persistence.config.QueryHints;
import org.eclipse.persistence.descriptors.DescriptorEvent;
import org.hibernate.validator.constraints.NotBlank;
import net.nan21.dnet.core.api.util.Duration;

@NamedQueries({
	@NamedQuery(
		name=ActActivityInstanceHistory.NQ_FIND_BY_ID,
		query="SELECT e FROM ActActivityInstanceHistory e WHERE  e.id = :pId ",
		hints=@QueryHint(name=QueryHints.BIND_PARAMETERS, value=HintValues.TRUE)
	)
	,@NamedQuery(
		name=ActActivityInstanceHistory.NQ_FIND_BY_IDS,
		query="SELECT e FROM ActActivityInstanceHistory e WHERE  e.id in :pIds",
		hints=@QueryHint(name=QueryHints.BIND_PARAMETERS, value=HintValues.TRUE)
	)
})
@Entity
@Table(
	name=ActActivityInstanceHistory.TABLE_NAME
)
@Cache(type=CacheType.NONE)
@Customizer(DefaultEventHandler.class)
public class ActActivityInstanceHistory  implements IModelWithId {
	
	public static final String TABLE_NAME = "ACT_HI_ACTINST";
	public static final String SEQUENCE_NAME = "ACT_HI_ACTINST_SEQ";
	
	private static final long serialVersionUID = -8865917134914502125L;
	
	/**
	 * Named query find by ID.
	 */ 
	public static final String NQ_FIND_BY_ID = "ActActivityInstanceHistory.findById";
	
	/**
	 * Named query find by IDs.
	 */     
	public static final String NQ_FIND_BY_IDS = "ActActivityInstanceHistory.findByIds";
	
	@Column(name="ID_", nullable=false, length=64)
	@NotBlank
	@Id
	@GeneratedValue(generator=SEQUENCE_NAME)
	private String id;
	
	@Column(name="PROC_INST_ID_", length=64)
	private String processInstanceId;
	
	@Column(name="EXECUTION_ID_", length=255)
	private String executionId;
	
	@Column(name="ACT_ID_", length=255)
	private String activityId;
	
	@Column(name="ACT_NAME_", length=255)
	private String activityName;
	
	@Column(name="ACT_TYPE_", length=255)
	private String activityType;
	
	@Column(name="ASSIGNEE_", length=32)
	private String assignee;
	
	@Temporal(TemporalType.TIMESTAMP)
	@Column(name="START_TIME_", nullable=false )
	@NotNull
	private Date startTime;
	
	@Temporal(TemporalType.TIMESTAMP)
	@Column(name="END_TIME_" )
	private Date endTime;
	
	@Column(name="DURATION_")
	private Long duration;
	
	@ManyToOne(fetch=FetchType.LAZY, targetEntity=ActProcessDefinition.class)
	@JoinColumn(name="PROC_DEF_ID_", referencedColumnName="ID_")
	private ActProcessDefinition processDefinition;
	
	public String getId() {
		return this.id;
	}
	
	public void setId(String id) {
		this.id = id;
	}
	
	public String getProcessInstanceId() {
		return this.processInstanceId;
	}
	
	public void setProcessInstanceId(String processInstanceId) {
		this.processInstanceId = processInstanceId;
	}
	
	public String getExecutionId() {
		return this.executionId;
	}
	
	public void setExecutionId(String executionId) {
		this.executionId = executionId;
	}
	
	public String getActivityId() {
		return this.activityId;
	}
	
	public void setActivityId(String activityId) {
		this.activityId = activityId;
	}
	
	public String getActivityName() {
		return this.activityName;
	}
	
	public void setActivityName(String activityName) {
		this.activityName = activityName;
	}
	
	public String getActivityType() {
		return this.activityType;
	}
	
	public void setActivityType(String activityType) {
		this.activityType = activityType;
	}
	
	public String getAssignee() {
		return this.assignee;
	}
	
	public void setAssignee(String assignee) {
		this.assignee = assignee;
	}
	
	public Date getStartTime() {
		return this.startTime;
	}
	
	public void setStartTime(Date startTime) {
		this.startTime = startTime;
	}
	
	public Date getEndTime() {
		return this.endTime;
	}
	
	public void setEndTime(Date endTime) {
		this.endTime = endTime;
	}
	
	public Long getDuration() {
		return this.duration;
	}
	
	public void setDuration(Long duration) {
		this.duration = duration;
	}
	
	@Transient
	public String getDurationText() {
		 return Duration.format(this.duration);
	}
	
	public void setDurationText(String durationText) {
	}
	
	@Transient
	public Long getVersion() {
		return 1L; 
	}
	
	public void setVersion(Long version) {
	}
	
	public ActProcessDefinition getProcessDefinition() {
		return this.processDefinition;
	}
	
	public void setProcessDefinition(ActProcessDefinition processDefinition) {
		this.processDefinition = processDefinition;
	}
	
	public void aboutToInsert(DescriptorEvent event) {
	
	}
	
	public void aboutToUpdate(DescriptorEvent  event) {
	}
}
