/* 
 * DNet eBusiness Suite
 * Copyright: Nan21 Electronics SRL. All rights reserved.
 * Use is subject to license terms.
 */

package net.nan21.dnet.module.ad.workflow.domain.entity;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.QueryHint;
import javax.persistence.Table;
import javax.persistence.Transient;
import net.nan21.dnet.core.api.model.IModelWithId;
import net.nan21.dnet.core.domain.eventhandler.DefaultEventHandler;
import org.eclipse.persistence.annotations.Cache;
import org.eclipse.persistence.annotations.CacheType;
import org.eclipse.persistence.annotations.Customizer;
import org.eclipse.persistence.config.HintValues;
import org.eclipse.persistence.config.QueryHints;
import org.eclipse.persistence.descriptors.DescriptorEvent;
import org.hibernate.validator.constraints.NotBlank;

@NamedQueries({
	@NamedQuery(
		name=ActIdentityInfo.NQ_FIND_BY_ID,
		query="SELECT e FROM ActIdentityInfo e WHERE  e.id = :pId ",
		hints=@QueryHint(name=QueryHints.BIND_PARAMETERS, value=HintValues.TRUE)
	)
	,@NamedQuery(
		name=ActIdentityInfo.NQ_FIND_BY_IDS,
		query="SELECT e FROM ActIdentityInfo e WHERE  e.id in :pIds",
		hints=@QueryHint(name=QueryHints.BIND_PARAMETERS, value=HintValues.TRUE)
	)
})
@Entity
@Table(
	name=ActIdentityInfo.TABLE_NAME
)
@Cache(type=CacheType.NONE)
@Customizer(DefaultEventHandler.class)
public class ActIdentityInfo  implements IModelWithId {
	
	public static final String TABLE_NAME = "ACT_ID_INFO";
	public static final String SEQUENCE_NAME = "ACT_ID_INFO_SEQ";
	
	private static final long serialVersionUID = -8865917134914502125L;
	
	/**
	 * Named query find by ID.
	 */ 
	public static final String NQ_FIND_BY_ID = "ActIdentityInfo.findById";
	
	/**
	 * Named query find by IDs.
	 */     
	public static final String NQ_FIND_BY_IDS = "ActIdentityInfo.findByIds";
	
	@Column(name="ID_", nullable=false, length=64)
	@NotBlank
	@Id
	@GeneratedValue(generator=SEQUENCE_NAME)
	private String id;
	
	@Column(name="REV_")
	private Integer revision;
	
	@Column(name="USER_ID_", length=64)
	private String userId;
	
	@Column(name="TYPE_", length=255)
	private String type;
	
	@Column(name="KEY_", nullable=false, length=255)
	@NotBlank
	private String key;
	
	@Column(name="VALUE_", nullable=false, length=255)
	@NotBlank
	private String value;
	
	@Column(name="PWD_", nullable=false, length=255)
	@NotBlank
	private String password;
	
	@Column(name="PARENT_ID_", length=255)
	private String parentId;
	
	public String getId() {
		return this.id;
	}
	
	public void setId(String id) {
		this.id = id;
	}
	
	public Integer getRevision() {
		return this.revision;
	}
	
	public void setRevision(Integer revision) {
		this.revision = revision;
	}
	
	public String getUserId() {
		return this.userId;
	}
	
	public void setUserId(String userId) {
		this.userId = userId;
	}
	
	public String getType() {
		return this.type;
	}
	
	public void setType(String type) {
		this.type = type;
	}
	
	public String getKey() {
		return this.key;
	}
	
	public void setKey(String key) {
		this.key = key;
	}
	
	public String getValue() {
		return this.value;
	}
	
	public void setValue(String value) {
		this.value = value;
	}
	
	public String getPassword() {
		return this.password;
	}
	
	public void setPassword(String password) {
		this.password = password;
	}
	
	public String getParentId() {
		return this.parentId;
	}
	
	public void setParentId(String parentId) {
		this.parentId = parentId;
	}
	
	@Transient
	public Long getVersion() {
		return 1L; 
	}
	
	public void setVersion(Long version) {
	}
	
	public void aboutToInsert(DescriptorEvent event) {
	
	}
	
	public void aboutToUpdate(DescriptorEvent  event) {
	}
}
