/* 
 * DNet eBusiness Suite
 * Copyright: Nan21 Electronics SRL. All rights reserved.
 * Use is subject to license terms.
 */

package net.nan21.dnet.module.ad.workflow.domain.entity;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.QueryHint;
import javax.persistence.Table;
import javax.persistence.UniqueConstraint;
import javax.validation.constraints.NotNull;
import net.nan21.dnet.core.domain.eventhandler.DefaultEventHandler;
import net.nan21.dnet.core.domain.model.AbstractType;
import net.nan21.dnet.module.ad.workflow.domain.entity.WfDefNode;
import org.eclipse.persistence.annotations.Customizer;
import org.eclipse.persistence.config.HintValues;
import org.eclipse.persistence.config.QueryHints;
import org.eclipse.persistence.descriptors.DescriptorEvent;
import org.hibernate.validator.constraints.NotBlank;

@NamedQueries({
	@NamedQuery(
		name=WfDefNodeField.NQ_FIND_BY_ID,
		query="SELECT e FROM WfDefNodeField e WHERE e.clientId = :pClientId and e.id = :pId ",
		hints=@QueryHint(name=QueryHints.BIND_PARAMETERS, value=HintValues.TRUE)
	)
	,@NamedQuery(
		name=WfDefNodeField.NQ_FIND_BY_IDS,
		query="SELECT e FROM WfDefNodeField e WHERE e.clientId = :pClientId and e.id in :pIds",
		hints=@QueryHint(name=QueryHints.BIND_PARAMETERS, value=HintValues.TRUE)
	)
	,@NamedQuery(
		name=WfDefNodeField.NQ_FIND_BY_NAME,
		query="SELECT e FROM WfDefNodeField e WHERE e.clientId = :pClientId and e.name = :pName",
		hints=@QueryHint(name=QueryHints.BIND_PARAMETERS, value=HintValues.TRUE)
	)
})
@Entity
@Table(
	name=WfDefNodeField.TABLE_NAME
	,uniqueConstraints={
		@UniqueConstraint( 
			name=WfDefNodeField.TABLE_NAME+"_UK1"
			,columnNames={"CLIENTID","NAME"}
		)
	}
)
@Customizer(DefaultEventHandler.class)
public class WfDefNodeField extends AbstractType  {
	
	public static final String TABLE_NAME = "AD_WFDEF_NODE_FLD";
	public static final String SEQUENCE_NAME = "AD_WFDEF_NODE_FLD_SEQ";
	
	private static final long serialVersionUID = -8865917134914502125L;
	
	/**
	 * Named query find by ID.
	 */ 
	public static final String NQ_FIND_BY_ID = "WfDefNodeField.findById";
	
	/**
	 * Named query find by IDs.
	 */     
	public static final String NQ_FIND_BY_IDS = "WfDefNodeField.findByIds";
	
	/**
	 * Named query find by unique key: Name.
	 */
	public static final String NQ_FIND_BY_NAME = "WfDefNodeField.findByName";
	
	/**
			 * System generated unique identifier.
			 */
	@Column(name="ID", nullable=false)
	@NotNull
	@Id
	@GeneratedValue(generator=SEQUENCE_NAME)
	private Long id;
	
	@Column(name="REQUIRED", nullable=false)
	@NotNull
	private Boolean required;
	
	@Column(name="TYPE", nullable=false, length=16)
	@NotBlank
	private String type;
	
	@ManyToOne(fetch=FetchType.LAZY, targetEntity=WfDefNode.class)
	@JoinColumn(name="NODE_ID", referencedColumnName="ID")
	private WfDefNode node;
	
	public Long getId() {
		return this.id;
	}
	
	public void setId(Long id) {
		this.id = id;
	}
	
	public Boolean getRequired() {
		return this.required;
	}
	
	public void setRequired(Boolean required) {
		this.required = required;
	}
	
	public String getType() {
		return this.type;
	}
	
	public void setType(String type) {
		this.type = type;
	}
	
	public WfDefNode getNode() {
		return this.node;
	}
	
	public void setNode(WfDefNode node) {
		if (node != null ) {
			this.__validate_client_context__(node.getClientId());
		}
		this.node = node;
	}
	
	public void aboutToInsert(DescriptorEvent event) {
		super.aboutToInsert(event);
	
		if (this.getRequired() == null ) {
			event.updateAttributeWithObject("required",false);
		}
	}
}
